==> 0.0.1.tar.gz: example/lib/native_callback_shortcuts_example.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

void main() => runApp(const MyApp());

///An example of using the native [Shortcuts] widget to implement keyboard
///shortcuts
class MyApp extends StatelessWidget {
  const MyApp({Key? key}) : super(key: key);

  static const String _title = 'native shortcut example';

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: _title,
      home: Scaffold(
        appBar: AppBar(title: const Text(_title),),
        body: const Center(
          child: MyStatefulWidget(),
        ),
      ),
    );
  }
}

class IncrementIntent extends Intent {
  const IncrementIntent();
}

class DecrementIntent extends Intent {
  const DecrementIntent();
}

class MyStatefulWidget extends StatefulWidget {
  const MyStatefulWidget({Key? key}) : super(key: key);

  @override
  _MyStatefulWidgetState createState() => _MyStatefulWidgetState();
}

class _MyStatefulWidgetState extends State<MyStatefulWidget> {
  int count = 0;
  @override
  Widget build(BuildContext context) {
    return CallbackShortcuts(
      bindings: {
        const SingleActivator(LogicalKeyboardKey.keyA, control: true) : () {
          setState(() {
            count++;
          });
        },
        const SingleActivator(LogicalKeyboardKey.keyS, control: true) : () {
          setState(() {
            count--;
          });
        }
      },
      child: Focus(
        autofocus: true,
        child: Column(
          children: [
            const Text('Up arrow for adding, down arrow to subtract'),
            Text('count: $count'),
          ],
        ),
      ),
    );
  }
}

==> 0.0.2.tar.gz: example/lib/native_callback_shortcuts_example.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

void main() => runApp(const MyApp());

///An example of using the native widget to implement keyboard
///shortcuts
class MyApp extends StatelessWidget {
  const MyApp({Key? key}) : super(key: key);

  static const String _title = 'keymap shortcut example';

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: _title,
      home: Scaffold(
        appBar: AppBar(title: const Text(_title),),
        body: const Center(
          child: MyStatefulWidget(),
        ),
      ),
    );
  }
}

class MyStatefulWidget extends StatefulWidget {
  const MyStatefulWidget({Key? key}) : super(key: key);

  @override
  _MyStatefulWidgetState createState() => _MyStatefulWidgetState();
}

class _MyStatefulWidgetState extends State<MyStatefulWidget> {

  int count = 0;

  @override
  Widget build(BuildContext context) {
    return CallbackShortcuts(
      bindings: {
        const SingleActivator(LogicalKeyboardKey.keyA, control: true) : () {
          setState(() {
            count++;
          });
        },
        const SingleActivator(LogicalKeyboardKey.keyS, control: true) : () {
          setState(() {
            count--;
          });
        }
      },
      child: Focus(
        autofocus: true,
        child: Column(
          children: [
            const Text('Up arrow for adding, down arrow to subtract'),
            Text('count: $count'),
          ],
        ),
      ),
    );
  }
}
